@@ -1,8 +1,9 @@
 package Lingua::EN::Fractions;
-$Lingua::EN::Fractions::VERSION = '0.04';
-use 5.006;
+$Lingua::EN::Fractions::VERSION = '0.05';
+use 5.008;
 use strict;
 use warnings;
+use utf8;
 
 use parent 'Exporter';
 use Lingua::EN::Numbers qw/ num2en num2en_ordinal /;
@@ -15,6 +16,27 @@ my %special_denominators =
     4 => { singular => 'quarter', plural => 'quarter' },
 );
 
+my %unicode =
+(
+    '¼' => '1/4',
+    '½' => '1/2',
+    '¾' => '3/4',
+    '⅓' => '1/3',
+    '⅔' => '2/3',
+    '⅕' => '1/5',
+    '⅖' => '2/5',
+    '⅗' => '3/5',
+    '⅘' => '4/5',
+    '⅙' => '1/6',
+    '⅚' => '5/6',
+    '⅛' => '1/8',
+    '⅜' => '3/8',
+    '⅝' => '5/8',
+    '⅞' => '7/8',
+    '⁄' => '/',     # FRACTION SLASH &#8260;
+);
+my $unicode_regexp = join('|', keys %unicode);
+
 sub fraction2words
 {
     my $number = shift;
@@ -32,6 +54,8 @@ sub fraction2words
                         $
                      |x;
 
+    $number =~ s/($unicode_regexp)/ $unicode{$1}/;
+
     if (my ($negate, $preamble, $wholepart, $numerator, $denominator) = $number =~ $fraction) {
         my $denominator_as_words = do {
             if (exists $special_denominators{$denominator}) {
@@ -70,6 +94,8 @@ sub fraction2words
 
 1;
 
+=encoding utf8
+
 =head1 NAME
 
 Lingua::EN::Fractions - convert "3/4" into "three quarters", etc
@@ -112,16 +138,39 @@ You can also pass a whole number ahead of the fraction:
 Note that instead of "one and one half",
 you'll get back "one and a half".
 
+=head2 Unicode fraction characters
+
+As of 0.05, certain Unicode characters are also supported.
+For example:
+
+ fraction2words('½')        # "one half"
+ fraction2words('1⅜')       # "one and three eighths"
+ fraction2words('-1⅘')      # "minus one and four fifths"
+
+You can also use the Unicode FRACTION SLASH, which is a different
+character from the regular slash:
+
+ fraction2words('1/2')      # "one half"
+ fraction2words('1⁄2')      # "one half"
+
+At the moment, the DIVISION SLASH character isn't handled.
+Feel free to tell me if you think I got that wrong.
+
+=head2 Working with Number::Fraction
+
 You can also pass in a fraction represented using L<Number::Fraction>:
 
  $fraction = Number::Fraction->new(2, 7);
  $as_words = fraction2words($fraction);    # "two sevenths"
 
+=head1 CAVEATS
+
 At the moment, no attempt is made to simplify the fraction,
 so C<'5/2'> will return "five halves" rather than "two and a half".
+Note though, that if you're using L<Number::Fraction>, then it
+does normalise fractions, so "3/6" will become "1/2".
 
 At the moment it's not very robust to weird inputs.
-I may add support for Unicode fractions as well.
 
 =head1 SEE ALSO
 
